var assert = require("assert"),
sift = require("..");

describe(__filename + "#", function() {

  it("doesn't sort arrays", function () {
    var values = sift({
      $or: [3, 2, 1]
    }, [9,8,7,6,5,4,3,2,1]);


    assert.equal(values.length, 3);
    assert.equal(values[0], 3);
    assert.equal(values[1], 2);
    assert.equal(values[2], 1);
  });

  it("can create a custom selector, and use it", function () {
    var sifter = sift({ age: { $gt: 5}}, function (item) {
      return item.person;
    });

    var people = [{ person: { age: 6 }}],
    filtered = sifter(people);


    assert.equal(filtered.length, 1);
    assert.equal(filtered[0], people[0]);
  });

  it("throws an errror if the selector is invalid", function () {
    
    var err;
    try {
      sift({$aaa:1}, 1).test("b");
    } catch (e) {
      err = e;
    }

    assert.equal(err.message, "Unknown sift selector 1");

  });

  it("can use a custom selector as the 3rd param", function () {

    var people = [{ person: { age: 6 }}];

    var filtered = sift({ age: { $gt: 5}}, people, function (item) {
      return item.person;
    });

    assert.equal(filtered.length, 1);
    assert.equal(filtered[0], people[0]);
  });

  it("throws an error", function () {
    var err;
    try {
      sift({$aaa:1}).test("b");
    } catch (e) {
      err = e;
    }

    assert.equal(err.message, "Unknown operator $aaa.");
  })
});
